<?php

namespace Drupal\paragraphs_access\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\Routing\Route;
use Drupal\paragraphs\ParagraphInterface;

/**
 * Determines access to operations on the field collection item's host.
 */
class ParagraphsAccessGrantsOperationCheck implements AccessInterface {

  /**
   * Checks access to the operation on the paragraph item's parent.
   *
   * @param \Symfony\Component\Routing\Route $route
   *   The currently request route.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The currently logged in account.
   * @param object|null $revision
   *   The current paragraph revision id.
   * @param \Drupal\paragraphs\ParagraphInterface $paragraph
   *   The paragraph to test access to.
   *
   *   TODO: Document params.
   *
   * @return string
   *   A \Drupal\Core\Access\AccessInterface constant value.
   */
  public function access(Route $route, AccountInterface $account, $revision = NULL, ParagraphInterface $paragraph = NULL) {
    $operation = $route->getRequirement('_paragraphs_access_grants');
    return AccessResult::allowedIf($paragraph && $paragraph->access($operation, $account))->cachePerUser();
  }

}
