<?php

namespace Drupal\paragraphs_access\Plugin\sapi_ref\AccessProvider;

use Drupal\Core\Entity\Entity;
use Drupal\Core\Session\AccountInterface;
use Drupal\paragraphs\Entity\Paragraph;
use Drupal\sapi_ref\AccessProvider\AccessProvider;
use Drupal\sapi_ref\AccessProvider\AccessProviderInterface;

/**
 * SAPI Reference Access Provider for node_access.
 *
 * Wraps node_access_records and node_access_grants and formats them for
 * Search API References in Solr.
 *
 * @AccessProvider(
 *   id = "ParagraphsAccessProvider",
 *   label = @Translation("Paragraphs Access Provider"),
 *   description = @Translation("An access provider for paragraph items."),
 * )
 */
class ParagraphsAccessProvider extends AccessProvider implements AccessProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function getEntityRequirements(Entity $entity) {
    if ($entity instanceof Paragraph) {
      $grantStorage = \Drupal::service('paragraphs_access.grant_storage');
      $grants = $grantStorage->getRecordsFor($entity);

      $rules = [];
      foreach ($grants as $g) {
        if ($g["grant_view"]) {
          $rules[] = "paragraphs_access__" . $g["realm"] . "__" . $g["gid"];
        }
      }
      return $rules;
    }
    return parent::getEntityRequirements($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getUserGrants(AccountInterface $account) {
    $rules = [];
    $grantStorage = \Drupal::service('paragraphs_access.grant_storage');
    $grants = $grantStorage->getUserGrants("view", $account);
    foreach ($grants as $realm => $gids) {
      foreach ($gids as $gid) {
        $rules[] = "paragraphs_access__" . $realm . "__" . $gid;
      }
    }
    return $rules;
  }

}
